;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "navigel" "20251012.1517"
  "Facilitate the creation of tabulated-list based UIs."
  '((emacs   "25.1")
    (tablist "1.0"))
  :url "https://github.com/DamienCassou/navigel"
  :commit "3dc4aa6f7aeba6d36de806cfd23ca54b437135b0"
  :revdesc "3dc4aa6f7aeb"
  :authors '(("Damien Cassou" . "damien@cassou.me"))
  :maintainers '(("Damien Cassou" . "damien@cassou.me")))
